import threading

from cloudcontrol.server.clients import Client
from cloudcontrol.server.clients.host import HostClient


class HypervisorHandler(HostClient.RPC_HANDLER):
    """ Handler binded to an hv client.
    """


class HvClient(HostClient):

    """ A hv client connected to the cc-server.
    """

    ROLE = 'hv'
    RPC_HANDLER = HypervisorHandler

    def __init__(self, *args, **kwargs):
        super(HvClient, self).__init__(*args, **kwargs)
        self._hv_lock = threading.RLock()

    @property
    def hvlock(self):
        """ The lock used on hypervirsors for migration.
        """
        return self._hv_lock

    #
    # Children specific methods:
    #

    def execute(self, command):
        return self.conn.call('execute_command', command)

    def get_child_remote_tags(self, obj_id, tag):
        return self.conn.call('sub_tags', obj_id, (tag,))[tag]

    def vm_action(self, action, vms, *args, **kwargs):
        return self.conn.call(action, vms, *args, **kwargs)


Client.register_client_class(HvClient)
